@@ -2,24 +2,6 @@ use MooseX::Declare;
 
 class TSQL::AST::SQLFragment {
 
-use feature "switch";
-
-use TSQL::AST::Token::Begin;
-use TSQL::AST::Token::BeginCatch;
-use TSQL::AST::Token::BeginTry;
-use TSQL::AST::Token::Else;
-use TSQL::AST::Token::End;
-use TSQL::AST::Token::EndCatch;
-use TSQL::AST::Token::EndTry;
-use TSQL::AST::Token::GO;
-use TSQL::AST::Token::If;
-use TSQL::AST::Token::While;
-
-#use TSQL::AST::SQLIfStatement;
-#use TSQL::AST::SQLTryCatchBlock;
-#use TSQL::AST::SQLWhileStatement;
-#use TSQL::AST::SQLStatement;
-
 use Data::Dumper;
 
 =head1 NAME
@@ -32,6 +14,7 @@ Version 0.01_001
 
 =cut
 
+our $VERSION = '0.01';
 
 
 has 'tokenString' => (
@@ -101,6 +84,18 @@ It creates and returns a new TSQL::AST::SQLFragment object.
 
 This is the method which parses the split up SQL code.
 
+=head2 C<tokenString>
+
+=over 4
+
+=item * C<< $self->tokenString() >>
+
+=back
+
+This is the method that holds the raw input text corresponding to the parsed SQL fragment.
+Derived classes representing compound objects do not populate this field, but delegate it to
+their constituent parts.
+
 
 =head1 LIMITATIONS
 
